@@ -2,12 +2,14 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
 
+from .tax import TaxesResponse
 from ..base_model import BaseResponseModel
 
 
 class GroupProperties(BaseModel):
     group_id: Optional[str]
     values: Optional[Dict[str, Any]]
+    invoice_display_name: Optional[str]
 
 
 class GroupPropertiesList(BaseModel):
@@ -19,10 +21,13 @@ class Charge(BaseModel):
     billable_metric_id: Optional[str]
     charge_model: Optional[str]
     pay_in_advance: Optional[bool]
+    prorated: Optional[bool]
     invoiceable: Optional[bool]
+    invoice_display_name: Optional[str]
     min_amount_cents: Optional[int]
     properties: Optional[Dict[str, Any]]
     group_properties: Optional[GroupPropertiesList]
+    tax_codes: Optional[List[str]]
 
 
 class Charges(BaseModel):
@@ -35,10 +40,13 @@ class ChargeResponse(BaseResponseModel):
     billable_metric_code: Optional[str]
     charge_model: Optional[str]
     pay_in_advance: Optional[bool]
+    prorated: Optional[bool]
     invoiceable: Optional[bool]
+    invoice_display_name: Optional[str]
     min_amount_cents: Optional[int]
     properties: Optional[Dict[str, Any]]
     group_properties: Optional[GroupPropertiesList]
+    taxes: Optional[TaxesResponse]
 
 
 class ChargesResponse(BaseResponseModel):
